@@ -120,14 +120,12 @@ func TestSetupData(t *testing.T) {
 			t.Parallel()
 
 			piState := getTestPreInitState(t)
-			runner, err := js.New(
-				piState,
-				&loader.SourceData{
-					URL:  &url.URL{Path: "/script.js"},
-					Data: testCase.script,
-				},
-				nil,
-			)
+			sourceData := &loader.SourceData{
+				URL:  &url.URL{Path: "/script.js"},
+				Data: testCase.script,
+			}
+			moduleResolver := js.NewModuleResolver(loader.Dir(sourceData.URL), piState, nil)
+			runner, err := js.New(piState, sourceData, nil, moduleResolver)
 			require.NoError(t, err)
 
 			testState := getTestRunState(t, lib.Options{
