@@ -2,6 +2,7 @@ package state
 
 import (
 	"context"
+	"fmt"
 	"io"
 	"os"
 	"os/signal"
@@ -24,12 +25,17 @@ import (
 )
 
 const (
-	// BinaryProvisioningFeatureFlag defines the environment variable that enables the binary provisioning
-	BinaryProvisioningFeatureFlag = "K6_BINARY_PROVISIONING"
+	// AutoExtensionResolution defines the environment variable that enables using extensions natively
+	AutoExtensionResolution = "K6_AUTO_EXTENSION_RESOLUTION"
 
+	// communityExtensionsCatalog defines the catalog for community extensions
+	communityExtensionsCatalog = "oss"
+
+	// defaultBuildServiceURL defines the URL to the default (grafana hosted) build service
 	defaultBuildServiceURL = "https://ingest.k6.io/builder/api/v1"
-	defaultConfigFileName  = "config.json"
-	defaultBinaryCacheDir  = "builds"
+
+	defaultConfigFileName = "config.json"
+	defaultBinaryCacheDir = "builds"
 )
 
 // GlobalState contains the GlobalFlags and accessors for most of the global
@@ -175,20 +181,23 @@ type GlobalFlags struct {
 	LogFormat        string
 	Verbose          bool
 
-	BinaryProvisioning bool
-	BuildServiceURL    string
-	BinaryCache        string
+	AutoExtensionResolution   bool
+	BuildServiceURL           string
+	BinaryCache               string
+	EnableCommunityExtensions bool
 }
 
 // GetDefaultFlags returns the default global flags.
 func GetDefaultFlags(homeDir string, cacheDir string) GlobalFlags {
 	return GlobalFlags{
-		Address:          "localhost:6565",
-		ProfilingEnabled: false,
-		ConfigFilePath:   filepath.Join(homeDir, "k6", defaultConfigFileName),
-		LogOutput:        "stderr",
-		BuildServiceURL:  defaultBuildServiceURL,
-		BinaryCache:      filepath.Join(cacheDir, "k6", defaultBinaryCacheDir),
+		Address:                   "localhost:6565",
+		ProfilingEnabled:          false,
+		ConfigFilePath:            filepath.Join(homeDir, "k6", defaultConfigFileName),
+		LogOutput:                 "stderr",
+		AutoExtensionResolution:   true,
+		BuildServiceURL:           defaultBuildServiceURL,
+		EnableCommunityExtensions: false,
+		BinaryCache:               filepath.Join(cacheDir, "k6", defaultBinaryCacheDir),
 	}
 }
 
@@ -218,15 +227,36 @@ func getFlags(defaultFlags GlobalFlags, env map[string]string, args []string) Gl
 	if _, ok := env["K6_PROFILING_ENABLED"]; ok {
 		result.ProfilingEnabled = true
 	}
+	//  old name for the K6_AUTO_EXTENSION_RESOLUTION feature flag
+	//  maintained for backward compatibility to be removed in a future release
 	if v, ok := env["K6_BINARY_PROVISIONING"]; ok {
 		vb, err := strconv.ParseBool(v)
 		if err == nil {
-			result.BinaryProvisioning = vb
+			result.AutoExtensionResolution = vb
+		}
+	}
+	if v, ok := env["K6_AUTO_EXTENSION_RESOLUTION"]; ok {
+		vb, err := strconv.ParseBool(v)
+		if err == nil {
+			result.AutoExtensionResolution = vb
 		}
 	}
 	if val, ok := env["K6_BUILD_SERVICE_URL"]; ok {
 		result.BuildServiceURL = val
 	}
+	if v, ok := env["K6_ENABLE_COMMUNITY_EXTENSIONS"]; ok {
+		vb, err := strconv.ParseBool(v)
+		if err == nil {
+			result.EnableCommunityExtensions = vb
+		}
+	}
+
+	// adjust BuildServiceURL if community extensions are enable
+	// community extensions flag only takes effect if the default build service is used
+	// for custom build service URLs it has no effect (because the /oss path may not be implemented)
+	if result.EnableCommunityExtensions && result.BuildServiceURL == defaultBuildServiceURL {
+		result.BuildServiceURL = fmt.Sprintf("%s/%s", defaultBuildServiceURL, communityExtensionsCatalog)
+	}
 
 	// check if verbose flag is set
 	if slices.Contains(args, "-v") || slices.Contains(args, "--verbose") {
