@@ -329,7 +329,7 @@ func TestThresholdsRuntimeBehavior(t *testing.T) {
 			name:              "#2518: submetrics without values should be rendered under their parent metric #2518",
 			testFilename:      "thresholds/thresholds_on_submetric_without_samples.js",
 			expExitCode:       0,
-			expStdoutContains: "    one....................................: 0   0/s\n      { tag:xyz }..........................: 0   0/s\n",
+			expStdoutContains: "    one..................: 0   0/s\n      { tag:xyz }........: 0   0/s\n",
 		},
 		{
 			name:         "#2512: parsing threshold names containing parsable tokens should be valid",
@@ -340,7 +340,7 @@ func TestThresholdsRuntimeBehavior(t *testing.T) {
 			name:                 "#2520: thresholds over metrics without values should avoid division by zero and displaying NaN values",
 			testFilename:         "thresholds/empty_sink_no_nan.js",
 			expExitCode:          0,
-			expStdoutContains:    "rate...................................: 0.00%",
+			expStdoutContains:    "rate.................: 0.00%",
 			expStdoutNotContains: "NaN",
 		},
 	}
