@@ -109,12 +109,13 @@ func testRuntimeOptionsCase(t *testing.T, tc runtimeOptionsTestCase) {
 func TestRuntimeOptions(t *testing.T) {
 	t.Parallel()
 	var (
-		defaultCompatMode   = null.NewString("extended", false)
-		baseCompatMode      = null.NewString("base", true)
-		extendedCompatMode  = null.NewString("extended", true)
-		enhancedCompatMode  = null.NewString("experimental_enhanced", true)
-		defaultTracesOutput = null.NewString("none", false)
-		defaultSummaryMode  = null.NewString("compact", false)
+		defaultCompatMode                = null.NewString("extended", false)
+		baseCompatMode                   = null.NewString("base", true)
+		extendedCompatMode               = null.NewString("extended", true)
+		enhancedCompatMode               = null.NewString("experimental_enhanced", true)
+		defaultTracesOutput              = null.NewString("none", false)
+		defaultSummaryMode               = null.NewString("compact", false)
+		defaultNewMachineReadableSummary = null.NewBool(false, false)
 	)
 
 	runtimeOptionsTestCases := map[string]runtimeOptionsTestCase{
@@ -122,44 +123,48 @@ func TestRuntimeOptions(t *testing.T) {
 			useSysEnv: true,
 			// everything else is empty
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  nil,
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       nil,
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by default": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"test1": "val1"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by default with ext compat mode": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"test1": "val1", "K6_COMPATIBILITY_MODE": "extended"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    extendedCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         extendedCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by default with experimental_enhanced compat mode": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"test1": "val1", "K6_COMPATIBILITY_MODE": "experimental_enhanced"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    enhancedCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         enhancedCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by cli 1": {
@@ -167,11 +172,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1", "K6_COMPATIBILITY_MODE": "base"},
 			cliFlags:  []string{"--include-system-env-vars=false"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, true),
-				CompatibilityMode:    baseCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, true),
+				CompatibilityMode:         baseCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by cli 2": {
@@ -179,33 +185,36 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "true", "K6_COMPATIBILITY_MODE": "extended"},
 			cliFlags:  []string{"--include-system-env-vars=0", "--compatibility-mode=base"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, true),
-				CompatibilityMode:    baseCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, true),
+				CompatibilityMode:         baseCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled sys env by env": {
 			useSysEnv: true,
 			systemEnv: map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "false", "K6_COMPATIBILITY_MODE": "extended"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, true),
-				CompatibilityMode:    extendedCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, true),
+				CompatibilityMode:         extendedCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"enabled sys env by env": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "true", "K6_COMPATIBILITY_MODE": "extended"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, true),
-				CompatibilityMode:    extendedCompatMode,
-				Env:                  map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "true", "K6_COMPATIBILITY_MODE": "extended"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, true),
+				CompatibilityMode:         extendedCompatMode,
+				Env:                       map[string]string{"K6_INCLUDE_SYSTEM_ENV_VARS": "true", "K6_COMPATIBILITY_MODE": "extended"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"enabled sys env by default": {
@@ -213,11 +222,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1"},
 			cliFlags:  []string{},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"enabled sys env by cli 1": {
@@ -225,11 +235,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1"},
 			cliFlags:  []string{"--include-system-env-vars"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, true),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, true),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"enabled sys env by cli 2": {
@@ -237,11 +248,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1"},
 			cliFlags:  []string{"--include-system-env-vars=true"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, true),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, true),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"run only system env": {
@@ -249,11 +261,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1"},
 			cliFlags:  []string{},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"mixed system and cli env": {
@@ -261,11 +274,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1", "test2": ""},
 			cliFlags:  []string{"--env", "test3=val3", "-e", "test4", "-e", "test5="},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"mixed system and cli env 2": {
@@ -273,11 +287,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1", "test2": ""},
 			cliFlags:  []string{"--env", "test3=val3", "-e", "test4", "-e", "test5=", "--include-system-env-vars=1"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, true),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, true),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1", "test2": "", "test3": "val3", "test4": "", "test5": ""},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"disabled system env with cli params": {
@@ -285,11 +300,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1"},
 			cliFlags:  []string{"-e", "test2=overwriten", "-e", "test2=val2"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test2": "val2"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test2": "val2"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"overwriting system env with cli param": {
@@ -297,11 +313,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "val1sys"},
 			cliFlags:  []string{"--env", "test1=val1cli"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "val1cli"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "val1cli"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"error wrong compat mode env var value": {
@@ -340,11 +357,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "value 1"},
 			cliFlags:  []string{"--env", "test2=value 2"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "value 1", "test2": "value 2"},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "value 1", "test2": "value 2"},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"valid env vars with special chars": {
@@ -352,25 +370,27 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"test1": "value 1"},
 			cliFlags:  []string{"--env", "test2=value,2", "-e", `test3= ,  ,,, value, ,, 2!'@#,"`},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(true, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{"test1": "value 1", "test2": "value,2", "test3": ` ,  ,,, value, ,, 2!'@#,"`},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(true, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{"test1": "value 1", "test2": "value,2", "test3": ` ,  ,,, value, ,, 2!'@#,"`},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"summary and thresholds from env": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"K6_NO_THRESHOLDS": "false", "K6_NO_SUMMARY": "0", "K6_SUMMARY_EXPORT": "foo"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				NoThresholds:         null.NewBool(false, true),
-				NoSummary:            null.NewBool(false, true),
-				SummaryExport:        null.NewString("foo", true),
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				NoThresholds:              null.NewBool(false, true),
+				NoSummary:                 null.NewBool(false, true),
+				SummaryExport:             null.NewString("foo", true),
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"summary and thresholds from env overwritten by CLI": {
@@ -378,14 +398,15 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"K6_NO_THRESHOLDS": "FALSE", "K6_NO_SUMMARY": "0", "K6_SUMMARY_EXPORT": "foo"},
 			cliFlags:  []string{"--no-thresholds", "true", "--no-summary", "true", "--summary-export", "bar"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				NoThresholds:         null.NewBool(true, true),
-				NoSummary:            null.NewBool(true, true),
-				SummaryExport:        null.NewString("bar", true),
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				NoThresholds:              null.NewBool(true, true),
+				NoSummary:                 null.NewBool(true, true),
+				SummaryExport:             null.NewString("bar", true),
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"env var error detected even when CLI flags overwrite 1": {
@@ -403,22 +424,24 @@ func TestRuntimeOptions(t *testing.T) {
 		"traces output default": {
 			useSysEnv: false,
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         null.NewString("none", false),
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              null.NewString("none", false),
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"traces output from env": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"K6_TRACES_OUTPUT": "foo"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         null.NewString("foo", true),
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              null.NewString("foo", true),
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"traces output from env overwritten by CLI": {
@@ -426,22 +449,24 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"K6_TRACES_OUTPUT": "foo"},
 			cliFlags:  []string{"--traces-output", "bar"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         null.NewString("bar", true),
-				SummaryMode:          defaultSummaryMode,
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              null.NewString("bar", true),
+				SummaryMode:               defaultSummaryMode,
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"summary mode from env": {
 			useSysEnv: false,
 			systemEnv: map[string]string{"K6_SUMMARY_MODE": "full"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          null.NewString("full", true),
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               null.NewString("full", true),
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 		"summary mode from env overwritten by CLI": {
@@ -449,11 +474,12 @@ func TestRuntimeOptions(t *testing.T) {
 			systemEnv: map[string]string{"K6_SUMMARY_MODE": "full"},
 			cliFlags:  []string{"--summary-mode", "legacy"},
 			expRTOpts: lib.RuntimeOptions{
-				IncludeSystemEnvVars: null.NewBool(false, false),
-				CompatibilityMode:    defaultCompatMode,
-				Env:                  map[string]string{},
-				TracesOutput:         defaultTracesOutput,
-				SummaryMode:          null.NewString("legacy", true),
+				IncludeSystemEnvVars:      null.NewBool(false, false),
+				CompatibilityMode:         defaultCompatMode,
+				Env:                       map[string]string{},
+				TracesOutput:              defaultTracesOutput,
+				SummaryMode:               null.NewString("legacy", true),
+				NewMachineReadableSummary: defaultNewMachineReadableSummary,
 			},
 		},
 	}
