@@ -2,6 +2,7 @@ package js
 
 import (
 	"errors"
+	"sync"
 
 	"go.k6.io/k6/ext"
 	"go.k6.io/k6/internal/js/modules/k6"
@@ -49,10 +50,15 @@ func getInternalJSModules() map[string]interface{} {
 		// Experimental modules
 		"k6/experimental/csv":        csv.New(),
 		"k6/experimental/fs":         fs.New(),
-		"k6/experimental/redis":      redis.New(),
 		"k6/experimental/streams":    streams.New(),
 		"k6/experimental/websockets": expws.New(),
 
+		// Deprecated modules
+		"k6/experimental/redis": newWarnExperimentalModule(redis.New(),
+			"k6/experimental/redis has been deprecated and will be removed in future versions."+
+				" Please migrate to the new version by changing your import to 'k6/x/redis'."+
+				" Read more here: https://grafana.com/docs/k6/latest/javascript-api/k6-x-redis"),
+
 		// Removed modules
 		"k6/experimental/browser": newRemovedModule(
 			"k6/experimental/browser has been graduated, please use k6/browser instead." +
@@ -101,3 +107,21 @@ func (rm *removedModule) NewModuleInstance(vu modules.VU) modules.Instance {
 
 	return nil
 }
+
+type warnExperimentalModule struct {
+	once sync.Once
+	msg  string
+	base modules.Module
+}
+
+func newWarnExperimentalModule(base modules.Module, msg string) modules.Module {
+	return &warnExperimentalModule{
+		msg:  msg,
+		base: base,
+	}
+}
+
+func (w *warnExperimentalModule) NewModuleInstance(vu modules.VU) modules.Instance {
+	w.once.Do(func() { vu.InitEnv().Logger.Warn(w.msg) })
+	return w.base.NewModuleInstance(vu)
+}
