@@ -1,27 +1,15 @@
 package browser
 
 import (
-	"context"
 	"errors"
 	"fmt"
 
 	"github.com/grafana/sobek"
-	"github.com/mstoykov/k6-taskqueue-lib/taskqueue"
 
 	"go.k6.io/k6/internal/js/modules/k6/browser/common"
 	k6common "go.k6.io/k6/js/common"
 )
 
-func cancelableTaskQueue(ctx context.Context, registerCallback func() func(func() error)) *taskqueue.TaskQueue {
-	tq := taskqueue.New(registerCallback)
-
-	go func() {
-		<-ctx.Done()
-		tq.Close()
-	}()
-	return tq
-}
-
 // mapFrame to the JS module.
 //
 //nolint:funlen,gocognit,cyclop
@@ -463,7 +451,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			}), nil
 		},
 		"waitForNavigation": func(opts sobek.Value) (*sobek.Promise, error) {
-			return waitForNavigationBodyImpl(vu, f, opts)
+			return mapWaitForNavigation(vu, f, opts)
 		},
 		"waitForSelector": func(selector string, opts sobek.Value) (*sobek.Promise, error) {
 			popts := common.NewFrameWaitForSelectorOptions(f.Timeout())
@@ -486,7 +474,7 @@ func mapFrame(vu moduleVU, f *common.Frame) mapping {
 			})
 		},
 		"waitForURL": func(url sobek.Value, opts sobek.Value) (*sobek.Promise, error) {
-			return waitForURLBody(vu, f, url, opts)
+			return mapWaitForURL(vu, f, url, opts)
 		},
 	}
 	maps["$"] = func(selector string) *sobek.Promise {
