@@ -303,7 +303,7 @@ type browserContextAPI interface { //nolint:interfacebloat
 	SetGeolocation(geolocation *common.Geolocation) error
 	SetHTTPCredentials(httpCredentials common.Credentials) error
 	SetOffline(offline bool) error
-	WaitForEvent(event string, optsOrPredicate sobek.Value) (any, error)
+	WaitForEvent(event common.PageEventName, optsOrPredicate sobek.Value) (any, error)
 }
 
 // pageAPI is the interface of a single browser tab.
@@ -381,6 +381,7 @@ type pageAPI interface { //nolint:interfacebloat
 	WaitForSelector(selector string, opts sobek.Value) (*common.ElementHandle, error)
 	WaitForTimeout(timeout int64)
 	WaitForURL(url string, opts sobek.Value) (*sobek.Promise, error)
+	WaitForEvent(event string, opts sobek.Value) (*sobek.Promise, error)
 	WaitForResponse(url string, opts sobek.Value) (*sobek.Promise, error)
 	WaitForRequest(url string, opts sobek.Value) (*sobek.Promise, error)
 	Workers() []*common.Worker
@@ -593,6 +594,7 @@ type locatorAPI interface { //nolint:interfacebloat
 	Nth(nth int) *common.Locator
 	SelectOption(values sobek.Value, opts sobek.Value) ([]string, error)
 	Press(key string, opts sobek.Value) error
+	PressSequentially(text string, opts sobek.Value) error
 	Type(text string, opts sobek.Value) error
 	Hover(opts sobek.Value) error
 	Tap(opts sobek.Value) error
