@@ -97,6 +97,10 @@ type webSocket struct {
 	binaryType     string
 	protocol       string
 	extensions     []string
+
+	// fields for `close` event
+	closeCode   int
+	closeReason string
 }
 
 type ping struct {
@@ -494,27 +498,30 @@ func (w *webSocket) readPump(wg *sync.WaitGroup) {
 				data:  data,
 				t:     time.Now(),
 			})
-
 			continue
 		}
 
-		if !websocket.IsUnexpectedCloseError(
-			err, websocket.CloseNormalClosure, websocket.CloseGoingAway) {
-			// maybe still log it with debug level?
+		var closeErr *websocket.CloseError
+		var code int
+		var reason string
+		if errors.As(err, &closeErr) {
+			code = closeErr.Code
+			reason = closeErr.Text
+		}
+
+		if !websocket.IsUnexpectedCloseError(err, websocket.CloseNormalClosure, websocket.CloseGoingAway) {
 			err = nil
 		}
 
-		if err != nil {
-			w.tq.Queue(func() error {
-				_ = w.conn.Close() // TODO fix this
-				return nil
-			})
-		}
-
+		errLocal := err
 		w.tq.Queue(func() error {
-			return w.connectionClosedWithError(err)
+			if code != 0 {
+				w.closeCode = code
+				w.closeReason = reason
+			}
+			_ = w.conn.Close()
+			return w.connectionClosedWithError(errLocal)
 		})
-
 		return
 	}
 }
@@ -635,13 +642,17 @@ func (w *webSocket) send(msg sobek.Value) {
 			common.Throw(rt, fmt.Errorf("unsupported send type %T", o))
 		}
 
-		buffer := msg.ToObject(rt).Get("buffer")
-		ab, ok := buffer.Export().(sobek.ArrayBuffer)
-		if !ok {
+		var b []byte
+		err = rt.ExportTo(msg, &b)
+		if err != nil {
 			common.Throw(rt,
-				fmt.Errorf("buffer of an ArrayBufferView was not an ArrayBuffer but %T", buffer.Export()))
+				fmt.Errorf("got error while trying to export ArrayBufferView to bytes: %w", err))
+		}
+		w.writeQueueCh <- message{
+			mtype: websocket.BinaryMessage,
+			data:  b,
+			t:     time.Now(),
 		}
-		w.sendArrayBuffer(ab)
 	}
 }
 
@@ -727,26 +738,52 @@ func (w *webSocket) assertStateOpen() {
 	common.Throw(w.vu.Runtime(), errors.New("InvalidStateError"))
 }
 
-// TODO support code and reason
-func (w *webSocket) close(code int, reason string) {
+func isValidClientCloseCode(code int) bool {
+	return code == 1000 || (code >= 3000 && code <= 4999)
+}
+
+func isValidCloseReason(reason string) bool {
+	return len([]byte(reason)) <= 123
+}
+
+func (w *webSocket) close(code int, reason string) error {
 	if w.readyState == CLOSED || w.readyState == CLOSING {
-		return
+		return nil
 	}
-	w.readyState = CLOSING
+
+	if code != 0 && !isValidClientCloseCode(code) {
+		return fmt.Errorf(
+			"InvalidAccessError: Failed to execute 'close' on 'WebSocket': "+
+				"The close code must be either 1000, or between 3000 and 4999. %d is neither",
+			code,
+		)
+	}
+
+	if !isValidCloseReason(reason) {
+		return errors.New(
+			`SyntaxError: Failed to execute 'close' on 'WebSocket': The message must not be greater than 123 bytes`,
+		)
+	}
+
 	if code == 0 {
 		code = websocket.CloseNormalClosure
 	}
+
+	w.readyState = CLOSING
+	w.closeCode = code
+
 	w.writeQueueCh <- message{
 		mtype: websocket.CloseMessage,
 		data:  websocket.FormatCloseMessage(code, reason),
 		t:     time.Now(),
 	}
+
+	return nil
 }
 
 func (w *webSocket) queueClose() {
 	w.tq.Queue(func() error {
-		w.close(websocket.CloseNormalClosure, "")
-		return nil
+		return w.close(websocket.CloseNormalClosure, "")
 	})
 }
 
@@ -769,8 +806,11 @@ func (w *webSocket) connectionClosedWithError(err error) error {
 	close(w.done)
 
 	if err != nil {
-		if errList := w.callErrorListeners(err); errList != nil {
-			return errList // TODO ... still call the close listeners ?!?
+		var closeError *websocket.CloseError
+		if !errors.As(err, &closeError) || closeError.Code != websocket.CloseNormalClosure {
+			if errList := w.callErrorListeners(err); errList != nil {
+				return errList // TODO ... still call the close listeners ?!?
+			}
 		}
 	}
 	return w.callEventListeners(events.CLOSE)
@@ -779,7 +819,7 @@ func (w *webSocket) connectionClosedWithError(err error) error {
 // newEvent return an event implementing "implements" https://dom.spec.whatwg.org/#event
 // needs to be called on the event loop
 // TODO: move to events
-func (w *webSocket) newEvent(eventType string, t time.Time) *sobek.Object {
+func (w *webSocket) newEvent(eventType string, t time.Time, funcOptions ...func(*sobek.Object)) *sobek.Object {
 	rt := w.vu.Runtime()
 	o := rt.NewObject()
 
@@ -802,6 +842,10 @@ func (w *webSocket) newEvent(eventType string, t time.Time) *sobek.Object {
 		// https://w3c.github.io/hr-time/#dom-domhighrestimestamp
 	}), nil, sobek.FLAG_FALSE, sobek.FLAG_TRUE))
 
+	for _, funcOption := range funcOptions {
+		funcOption(o)
+	}
+
 	return o
 }
 
@@ -832,9 +876,25 @@ func (w *webSocket) callErrorListeners(e error) error { // TODO use the error ev
 }
 
 func (w *webSocket) callEventListeners(eventType string) error {
+	var event *sobek.Object
+	// TODO fix timestamp
+	// TODO: Add 'wasClean' boolean to close events per spec
+	if eventType == events.CLOSE {
+		event = w.newEvent(eventType, time.Now(), func(o *sobek.Object) {
+			rt := w.vu.Runtime()
+			if w.closeCode != 0 {
+				must(rt, o.DefineDataProperty("code",
+					rt.ToValue(w.closeCode), sobek.FLAG_FALSE, sobek.FLAG_FALSE, sobek.FLAG_TRUE))
+			}
+			must(rt, o.DefineDataProperty("reason",
+				rt.ToValue(w.closeReason), sobek.FLAG_FALSE, sobek.FLAG_FALSE, sobek.FLAG_TRUE))
+		})
+	} else {
+		event = w.newEvent(eventType, time.Now())
+	}
+
 	for _, listener := range w.eventListeners.all(eventType) {
-		// TODO the event here needs to be different and have an error (figure out it was for the close listeners)
-		if _, err := listener(w.newEvent(eventType, time.Now())); err != nil { // TODO fix timestamp
+		if _, err := listener(event); err != nil {
 			return err
 		}
 	}
