@@ -8,9 +8,9 @@ import (
 
 	"github.com/sirupsen/logrus"
 
+	"go.k6.io/k6/internal/ui/pb"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/metrics"
-	"go.k6.io/k6/ui/pb"
 )
 
 // BaseExecutor is a helper struct that contains common properties and methods
