@@ -173,7 +173,7 @@ var _ lib.Executor = &ConstantArrivalRate{}
 func (car *ConstantArrivalRate) Init(_ context.Context) error {
 	// err should always be nil, because Init() won't be called for executors
 	// with no work, as determined by their config's HasWork() method.
-	et, err := car.BaseExecutor.executionState.ExecutionTuple.GetNewExecutionTupleFromValue(car.config.MaxVUs.Int64)
+	et, err := car.executionState.ExecutionTuple.GetNewExecutionTupleFromValue(car.config.MaxVUs.Int64)
 	car.et = et
 	car.iterSegIndex = lib.NewSegmentedIndex(et)
 
