@@ -5,8 +5,8 @@ import (
 
 	"github.com/sirupsen/logrus"
 
+	"go.k6.io/k6/internal/output/cloud/expv2/pbcloud"
 	"go.k6.io/k6/metrics"
-	"go.k6.io/k6/output/cloud/expv2/pbcloud"
 )
 
 type pusher interface {
